@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_appconfig.type_defs import (
     ApplicationTypeDef,
@@ -42,30 +42,30 @@ __all__ = ("AppConfigClient",)
 
 
 class Exceptions:
-    BadRequestException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ConflictException: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    BadRequestException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class AppConfigClient:
     """
-    [AppConfig.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client)
+    [AppConfig.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.can_paginate)
         """
 
     def create_application(
         self, Name: str, Description: str = None, Tags: Dict[str, str] = None
     ) -> ApplicationTypeDef:
         """
-        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.create_application)
+        [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.create_application)
         """
 
     def create_configuration_profile(
@@ -79,7 +79,7 @@ class AppConfigClient:
         Tags: Dict[str, str] = None,
     ) -> ConfigurationProfileTypeDef:
         """
-        [Client.create_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
+        [Client.create_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
         """
 
     def create_deployment_strategy(
@@ -94,7 +94,7 @@ class AppConfigClient:
         Tags: Dict[str, str] = None,
     ) -> DeploymentStrategyTypeDef:
         """
-        [Client.create_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
+        [Client.create_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
         """
 
     def create_environment(
@@ -106,27 +106,27 @@ class AppConfigClient:
         Tags: Dict[str, str] = None,
     ) -> EnvironmentTypeDef:
         """
-        [Client.create_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.create_environment)
+        [Client.create_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.create_environment)
         """
 
     def delete_application(self, ApplicationId: str) -> None:
         """
-        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.delete_application)
+        [Client.delete_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.delete_application)
         """
 
     def delete_configuration_profile(self, ApplicationId: str, ConfigurationProfileId: str) -> None:
         """
-        [Client.delete_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
+        [Client.delete_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
         """
 
     def delete_deployment_strategy(self, DeploymentStrategyId: str) -> None:
         """
-        [Client.delete_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
+        [Client.delete_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
         """
 
     def delete_environment(self, ApplicationId: str, EnvironmentId: str) -> None:
         """
-        [Client.delete_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.delete_environment)
+        [Client.delete_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.delete_environment)
         """
 
     def generate_presigned_url(
@@ -137,12 +137,12 @@ class AppConfigClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
         """
 
     def get_application(self, ApplicationId: str) -> ApplicationTypeDef:
         """
-        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.get_application)
+        [Client.get_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.get_application)
         """
 
     def get_configuration(
@@ -154,71 +154,71 @@ class AppConfigClient:
         ClientConfigurationVersion: str = None,
     ) -> ConfigurationTypeDef:
         """
-        [Client.get_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.get_configuration)
+        [Client.get_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.get_configuration)
         """
 
     def get_configuration_profile(
         self, ApplicationId: str, ConfigurationProfileId: str
     ) -> ConfigurationProfileTypeDef:
         """
-        [Client.get_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
+        [Client.get_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
         """
 
     def get_deployment(
         self, ApplicationId: str, EnvironmentId: str, DeploymentNumber: int
     ) -> DeploymentTypeDef:
         """
-        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.get_deployment)
+        [Client.get_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.get_deployment)
         """
 
     def get_deployment_strategy(self, DeploymentStrategyId: str) -> DeploymentStrategyTypeDef:
         """
-        [Client.get_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
+        [Client.get_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
         """
 
     def get_environment(self, ApplicationId: str, EnvironmentId: str) -> EnvironmentTypeDef:
         """
-        [Client.get_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.get_environment)
+        [Client.get_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.get_environment)
         """
 
     def list_applications(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ApplicationsTypeDef:
         """
-        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.list_applications)
+        [Client.list_applications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.list_applications)
         """
 
     def list_configuration_profiles(
         self, ApplicationId: str, MaxResults: int = None, NextToken: str = None
     ) -> ConfigurationProfilesTypeDef:
         """
-        [Client.list_configuration_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
+        [Client.list_configuration_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
         """
 
     def list_deployment_strategies(
         self, MaxResults: int = None, NextToken: str = None
     ) -> DeploymentStrategiesTypeDef:
         """
-        [Client.list_deployment_strategies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
+        [Client.list_deployment_strategies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
         """
 
     def list_deployments(
         self, ApplicationId: str, EnvironmentId: str, MaxResults: int = None, NextToken: str = None
     ) -> DeploymentsTypeDef:
         """
-        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.list_deployments)
+        [Client.list_deployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.list_deployments)
         """
 
     def list_environments(
         self, ApplicationId: str, MaxResults: int = None, NextToken: str = None
     ) -> EnvironmentsTypeDef:
         """
-        [Client.list_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.list_environments)
+        [Client.list_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.list_environments)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ResourceTagsTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
         """
 
     def start_deployment(
@@ -232,31 +232,31 @@ class AppConfigClient:
         Tags: Dict[str, str] = None,
     ) -> DeploymentTypeDef:
         """
-        [Client.start_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.start_deployment)
+        [Client.start_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.start_deployment)
         """
 
     def stop_deployment(
         self, ApplicationId: str, EnvironmentId: str, DeploymentNumber: int
     ) -> DeploymentTypeDef:
         """
-        [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
+        [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.untag_resource)
         """
 
     def update_application(
         self, ApplicationId: str, Name: str = None, Description: str = None
     ) -> ApplicationTypeDef:
         """
-        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.update_application)
+        [Client.update_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.update_application)
         """
 
     def update_configuration_profile(
@@ -269,7 +269,7 @@ class AppConfigClient:
         Validators: List[ValidatorTypeDef] = None,
     ) -> ConfigurationProfileTypeDef:
         """
-        [Client.update_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
+        [Client.update_configuration_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
         """
 
     def update_deployment_strategy(
@@ -282,7 +282,7 @@ class AppConfigClient:
         GrowthType: Literal["LINEAR", "EXPONENTIAL"] = None,
     ) -> DeploymentStrategyTypeDef:
         """
-        [Client.update_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
+        [Client.update_deployment_strategy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
         """
 
     def update_environment(
@@ -294,12 +294,12 @@ class AppConfigClient:
         Monitors: List[MonitorTypeDef] = None,
     ) -> EnvironmentTypeDef:
         """
-        [Client.update_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.update_environment)
+        [Client.update_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.update_environment)
         """
 
     def validate_configuration(
         self, ApplicationId: str, ConfigurationProfileId: str, ConfigurationVersion: str
     ) -> None:
         """
-        [Client.validate_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
+        [Client.validate_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.36/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
         """
