@@ -31,6 +31,7 @@ __all__ = (
     "ConfigurationTypeDef",
     "DeploymentStrategyTypeDef",
     "DeploymentStrategiesTypeDef",
+    "DeploymentEventTypeDef",
     "DeploymentTypeDef",
     "DeploymentSummaryTypeDef",
     "DeploymentsTypeDef",
@@ -111,6 +112,24 @@ DeploymentStrategiesTypeDef = TypedDict(
     total=False,
 )
 
+DeploymentEventTypeDef = TypedDict(
+    "DeploymentEventTypeDef",
+    {
+        "EventType": Literal[
+            "PERCENTAGE_UPDATED",
+            "ROLLBACK_STARTED",
+            "ROLLBACK_COMPLETED",
+            "BAKE_TIME_STARTED",
+            "DEPLOYMENT_STARTED",
+            "DEPLOYMENT_COMPLETED",
+        ],
+        "TriggeredBy": Literal["USER", "APPCONFIG", "CLOUDWATCH_ALARM", "INTERNAL_ERROR"],
+        "Description": str,
+        "OccurredAt": datetime,
+    },
+    total=False,
+)
+
 DeploymentTypeDef = TypedDict(
     "DeploymentTypeDef",
     {
@@ -130,6 +149,7 @@ DeploymentTypeDef = TypedDict(
         "State": Literal[
             "BAKING", "VALIDATING", "DEPLOYING", "COMPLETE", "ROLLING_BACK", "ROLLED_BACK"
         ],
+        "EventLog": List[DeploymentEventTypeDef],
         "PercentageComplete": float,
         "StartedAt": datetime,
         "CompletedAt": datetime,
